/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { EventEmitter, TemplateRef } from '@angular/core';
import { ActionsLayout } from './models/actions-layout';
import { CardAction } from './models/card-action';
import { Orientation } from '../common/orientation';
import * as i0 from "@angular/core";
/**
 * Defines the action buttons of the Card ([see example]({% slug actions_card %})).
 * The Card actions can be used to perform operations related to the Card's content, such as saving, editing, or deleting.
 *
 * @example
 * ```html
 * <kendo-card-actions
 *   layout="end"
 *   orientation="horizontal">
 * </kendo-card-actions>
 * ```
 */
export declare class CardActionsComponent {
    hostClass: boolean;
    get stretchedClass(): boolean;
    get startClass(): boolean;
    get endClass(): boolean;
    get centerClass(): boolean;
    get verticalClass(): boolean;
    get horizontalClass(): boolean;
    /**
     * Specifies the orientation of the Card action buttons.
     *
     * @default 'horizontal'
     */
    orientation: Orientation;
    /**
     * Specifies the layout of the Card action buttons.
     *
     * @default 'start'
     */
    layout: ActionsLayout;
    /**
     * Defines the Card actions declaratively.
     * You can pass an array of `CardAction` objects or a `TemplateRef`.
     */
    set actions(value: CardAction[] | TemplateRef<any>);
    /**
     * Fires when you click an action button.
     */
    action: EventEmitter<CardAction>;
    /**
     * @hidden
     */
    actionsArray: CardAction[];
    /**
     * @hidden
     */
    actionsTemplate: TemplateRef<any>;
    /**
     * @hidden
     */
    onClick(action: CardAction): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<CardActionsComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<CardActionsComponent, "kendo-card-actions", never, { "orientation": { "alias": "orientation"; "required": false; }; "layout": { "alias": "layout"; "required": false; }; "actions": { "alias": "actions"; "required": false; }; }, { "action": "action"; }, never, ["*"], true, never>;
}
