/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { OnDestroy } from '@angular/core';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { Orientation } from '../common/orientation';
import * as i0 from "@angular/core";
/**
 * Represents the Kendo UI Card component for Angular.
 * Displays content in a structured container with customizable layout and styling ([Card overview]({% slug overview_card %})).
 *
 * @example
 * ```html
 * <kendo-card orientation="vertical">
 *   <kendo-card-header>
 *     <h5 kendoCardTitle>Card Title</h5>
 *   </kendo-card-header>
 *   <kendo-card-body>
 *     <p>Card content goes here.</p>
 *   </kendo-card-body>
 * </kendo-card>
 * ```
 * @remarks
 * Supported children components are: {@link CardFooterComponent}, {@link CardHeaderComponent}, {@link CardActionsComponent}, {@link CardBodyComponent}.
 */
export declare class CardComponent implements OnDestroy {
    private localizationService;
    hostClass: boolean;
    get widthStyle(): string;
    get vertical(): boolean;
    get horizontal(): boolean;
    /**
     * @hidden
     */
    direction: string;
    /**
     * Specifies the layout of the Card content.
     *
     * @default 'vertical'
     */
    orientation: Orientation;
    /**
     * Defines the width of the Card.
     *
     * @default '285px'
     */
    width: string;
    private dynamicRTLSubscription;
    private rtl;
    constructor(localizationService: LocalizationService);
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<CardComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<CardComponent, "kendo-card", never, { "orientation": { "alias": "orientation"; "required": false; }; "width": { "alias": "width"; "required": false; }; }, {}, never, ["*"], true, never>;
}
