/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { AvatarComponent } from "./avatar/avatar.component";
import { AvatarCustomMessagesComponent } from "./avatar/l10n/custom-messages.component";
import { CardActionsComponent } from "./card/card-actions.component";
import { CardBodyComponent } from "./card/card-body.component";
import { CardFooterComponent } from "./card/card-footer.component";
import { CardHeaderComponent } from "./card/card-header.component";
import { CardComponent } from "./card/card.component";
import { CardMediaDirective } from "./card/directives/card-media.directive";
import { CardSeparatorDirective } from "./card/directives/card-separator.directive";
import { CardSubtitleDirective } from "./card/directives/card-subtitle.directive";
import { CardTitleDirective } from "./card/directives/card-title.directive";
import { DrawerContainerComponent } from "./drawer/drawer-container.component";
import { DrawerContentComponent } from "./drawer/drawer-content.component";
import { DrawerComponent } from "./drawer/drawer.component";
import { DrawerFooterTemplateDirective, DrawerHeaderTemplateDirective, DrawerItemTemplateDirective, DrawerTemplateDirective } from "./drawer/template-directives";
import { ExpansionPanelTitleDirective } from "./expansionpanel/expansionpanel-title.directive";
import { ExpansionPanelComponent } from "./expansionpanel/expansionpanel.component";
import { GridLayoutComponent } from "./layouts/grid-layout.component";
import { GridLayoutItemComponent } from "./layouts/gridlayout-item.component";
import { StackLayoutComponent } from "./layouts/stack-layout.component";
import { PanelBarContentDirective } from "./panelbar/panelbar-content.directive";
import { PanelBarItemTemplateDirective } from "./panelbar/panelbar-item-template.directive";
import { PanelBarItemTitleDirective } from "./panelbar/panelbar-item-title.directive";
import { PanelBarItemComponent } from "./panelbar/panelbar-item.component";
import { PanelBarComponent } from "./panelbar/panelbar.component";
import { SplitterPaneComponent } from "./splitter/splitter-pane.component";
import { SplitterComponent } from "./splitter/splitter.component";
import { StepperCustomMessagesComponent } from "./stepper/localization/custom-messages.component";
import { StepperComponent } from "./stepper/stepper.component";
import { StepperIndicatorTemplateDirective, StepperLabelTemplateDirective, StepperStepTemplateDirective } from "./stepper/template-directives";
import { TabContentDirective } from "./tabstrip/directives/tab-content.directive";
import { TabTitleDirective } from "./tabstrip/directives/tab-title.directive";
import { TabStripCustomMessagesComponent } from "./tabstrip/localization/custom-messages.component";
import { TabStripTabComponent } from "./tabstrip/models/tabstrip-tab.component";
import { TabStripComponent } from "./tabstrip/tabstrip.component";
import { TileLayoutItemBodyComponent } from "./tilelayout/tilelayout-item-body.component";
import { TileLayoutItemHeaderComponent } from "./tilelayout/tilelayout-item-header.component";
import { TileLayoutItemComponent } from "./tilelayout/tilelayout-item.component";
import { TileLayoutComponent } from "./tilelayout/tilelayout.component";
import { TimelineCustomMessagesComponent } from "./timeline/localization/custom-messages.component";
import { TimelineCardActionsTemplateDirective } from "./timeline/templates/timeline-card-actions.directive";
import { TimelineCardBodyTemplateDirective } from "./timeline/templates/timeline-card-body.directive";
import { TimelineCardHeaderTemplateDirective } from "./timeline/templates/timeline-card-header.directive";
import { TimelineComponent } from "./timeline/timeline.component";
/**
 * Use the `KENDO_AVATAR` utility array to add all Avatar-related components and directives to a standalone Angular component.
 */
export declare const KENDO_AVATAR: readonly [typeof AvatarComponent, typeof AvatarCustomMessagesComponent];
/**
 * Use the `KENDO_CARD` utility array to add all Card-related components and directives to a standalone Angular component.
 */
export declare const KENDO_CARD: readonly [typeof CardComponent, typeof CardActionsComponent, typeof CardBodyComponent, typeof CardFooterComponent, typeof CardHeaderComponent, typeof CardMediaDirective, typeof CardSeparatorDirective, typeof CardSubtitleDirective, typeof CardTitleDirective];
/**
 * Use the `KENDO_DRAWER` utility array to add all Drawer-related components and directives to a standalone Angular component.
 */
export declare const KENDO_DRAWER: readonly [typeof DrawerComponent, typeof DrawerContainerComponent, typeof DrawerContentComponent, typeof DrawerTemplateDirective, typeof DrawerFooterTemplateDirective, typeof DrawerHeaderTemplateDirective, typeof DrawerItemTemplateDirective];
/**
 * Use the `KENDO_EXPANSIONPANEL` utility array to add all ExpansionPanel-related components and directives to a standalone Angular component.
 */
export declare const KENDO_EXPANSIONPANEL: readonly [typeof ExpansionPanelComponent, typeof ExpansionPanelTitleDirective];
/**
 * Use the `KENDO_GRIDLAYOUT` utility array to add all GridLayout-related components and directives to a standalone Angular component.
 */
export declare const KENDO_GRIDLAYOUT: readonly [typeof GridLayoutComponent, typeof GridLayoutItemComponent];
/**
 * Use the `KENDO_PANELBAR` utility array to add all PanelBar-related components and directives to a standalone Angular component.
 */
export declare const KENDO_PANELBAR: readonly [typeof PanelBarComponent, typeof PanelBarItemComponent, typeof PanelBarContentDirective, typeof PanelBarItemTemplateDirective, typeof PanelBarItemTitleDirective];
/**
 * Use the `KENDO_SPLITTER` utility array to add all Splitter-related components and directives to a standalone Angular component.
 */
export declare const KENDO_SPLITTER: readonly [typeof SplitterComponent, typeof SplitterPaneComponent];
/**
 * Use the `KENDO_STACKLAYOUT` utility array to add all StackLayout-related components and directives to a standalone Angular component.
 */
export declare const KENDO_STACKLAYOUT: readonly [typeof StackLayoutComponent];
/**
 * Use the `KENDO_STEPPER` utility array to add all Stepper-related components and directives to a standalone Angular component.
 */
export declare const KENDO_STEPPER: readonly [typeof StepperComponent, typeof StepperCustomMessagesComponent, typeof StepperIndicatorTemplateDirective, typeof StepperLabelTemplateDirective, typeof StepperStepTemplateDirective];
/**
 * Use the `KENDO_TABSTRIP` utility array to add all TabStrip-related components and directives to a standalone Angular component.
 */
export declare const KENDO_TABSTRIP: readonly [typeof TabStripComponent, typeof TabStripTabComponent, typeof TabContentDirective, typeof TabTitleDirective, typeof TabStripCustomMessagesComponent];
/**
 * Use the `KENDO_TILELAYOUT` utility array to add all TileLayout-related components and directives to a standalone Angular component.
 */
export declare const KENDO_TILELAYOUT: readonly [typeof TileLayoutComponent, typeof TileLayoutItemBodyComponent, typeof TileLayoutItemComponent, typeof TileLayoutItemHeaderComponent];
/**
 * Use the `KENDO_TIMELINE` utility array to add all Timeline-related components and directives to a standalone Angular component.
 */
export declare const KENDO_TIMELINE: readonly [typeof TimelineComponent, typeof TimelineCustomMessagesComponent, typeof TimelineCardActionsTemplateDirective, typeof TimelineCardBodyTemplateDirective, typeof TimelineCardHeaderTemplateDirective];
/**
 * Use the `KENDO_LAYOUT` utility array to add all `@progress/kendo-angular-layout`-related components and directives to a standalone Angular component.
 */
export declare const KENDO_LAYOUT: readonly [typeof AvatarComponent, typeof AvatarCustomMessagesComponent, typeof CardComponent, typeof CardActionsComponent, typeof CardBodyComponent, typeof CardFooterComponent, typeof CardHeaderComponent, typeof CardMediaDirective, typeof CardSeparatorDirective, typeof CardSubtitleDirective, typeof CardTitleDirective, typeof DrawerComponent, typeof DrawerContainerComponent, typeof DrawerContentComponent, typeof DrawerTemplateDirective, typeof DrawerFooterTemplateDirective, typeof DrawerHeaderTemplateDirective, typeof DrawerItemTemplateDirective, typeof ExpansionPanelComponent, typeof ExpansionPanelTitleDirective, typeof GridLayoutComponent, typeof GridLayoutItemComponent, typeof PanelBarComponent, typeof PanelBarItemComponent, typeof PanelBarContentDirective, typeof PanelBarItemTemplateDirective, typeof PanelBarItemTitleDirective, typeof SplitterComponent, typeof SplitterPaneComponent, typeof StackLayoutComponent, typeof StepperComponent, typeof StepperCustomMessagesComponent, typeof StepperIndicatorTemplateDirective, typeof StepperLabelTemplateDirective, typeof StepperStepTemplateDirective, typeof TabStripComponent, typeof TabStripTabComponent, typeof TabContentDirective, typeof TabTitleDirective, typeof TabStripCustomMessagesComponent, typeof TileLayoutComponent, typeof TileLayoutItemBodyComponent, typeof TileLayoutItemComponent, typeof TileLayoutItemHeaderComponent, typeof TimelineComponent, typeof TimelineCustomMessagesComponent, typeof TimelineCardActionsTemplateDirective, typeof TimelineCardBodyTemplateDirective, typeof TimelineCardHeaderTemplateDirective];
