/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { DrawerComponent } from './drawer.component';
import * as i0 from "@angular/core";
/**
 * Serves as a container for the [Drawer component]({% slug overview_drawer %}) and its content.
 *
 * @example
 * ```html
 * <kendo-drawer-container>
 *   <kendo-drawer [items]="items"></kendo-drawer>
 *   <kendo-drawer-content>
 *     <h1>Main Content</h1>
 *   </kendo-drawer-content>
 * </kendo-drawer-container>
 * ```
 * @remarks
 * Supported children components are: {@link DrawerComponent}, {@link DrawerContentComponent}.
 */
export declare class DrawerContainerComponent {
    private localizationService;
    get hostClass(): boolean;
    get overlayClass(): boolean;
    get miniClass(): boolean;
    get pushClass(): boolean;
    get isExpandedClass(): boolean;
    /**
     * @hidden
     */
    direction: string;
    /**
     * @hidden
     */
    drawer: DrawerComponent;
    private dynamicRTLSubscription;
    private rtl;
    constructor(localizationService: LocalizationService);
    ngOnDestroy(): void;
    /**
     * @hidden
     */
    get overlay(): boolean;
    /**
     * @hidden
     */
    closeDrawer(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<DrawerContainerComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DrawerContainerComponent, "kendo-drawer-container", never, {}, {}, ["drawer"], ["*"], true, never>;
}
