/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { SVGIcon } from "@progress/kendo-svg-icons";
/**
 * Defines an interface for the Drawer items.
 */
export interface DrawerItem {
    /**
     * Defines the CSS classes that render on the item element of the Drawer.
     * Supports the type of values that [`ngClass`](link:site.data.urls.angular['ngclassapi']) supports.
     */
    cssClass?: any;
    /**
     * Defines the CSS styles that render on the item element of the Drawer.
     * Supports the type of values that [`ngStyle`](link:site.data.urls.angular['ngstyleapi']) supports.
     */
    cssStyle?: any;
    /**
     * Specifies if the Drawer item is disabled.
     *
     */
    disabled?: boolean;
    /**
     * Defines the name for an existing icon in a Kendo UI theme.
     * The icon renders inside the Drawer item by the `kendo-icon` element.
     */
    icon?: string;
    /**
     * Defines a CSS class or multiple classes separated by spaces.
     * You can apply these classes to a `span` element inside the Drawer item to use custom icons.
     */
    iconClass?: string;
    /**
     * Defines an SVG icon to render inside the Drawer Item.
     * You can use either an [existing Kendo SVG icon](slug:svgicon_list) or a custom one.
     */
    svgIcon?: SVGIcon;
    /**
     * Specifies the `id` of the Drawer item.
     */
    id?: number | string;
    /**
     * Specifies the parentId of the Drawer item.
     */
    parentId?: number | string;
    /**
     * Specifies if the Drawer item is initially selected.
     *
     */
    selected?: boolean;
    /**
     * Specifies if this is a separator item.
     * If set to `true`, only the `cssClass` and `cssStyle` fields render.
     *
     */
    separator?: boolean;
    /**
     * Specifies the text content of the Drawer item.
     */
    text?: string;
}
