/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TemplateRef } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * Defines a template that specifies the content of the Drawer.
 * To define the template, nest an `<ng-template>` tag with the `kendoDrawerTemplate` directive inside the `<kendo-drawer>` tag.
 * Using this template directive overrides all other templates, for example, `kendoDrawerHeaderTemplate` and `kendoDrawerItemTemplate`.
 *
 * @example
 * ```html
 * <kendo-drawer>
 *   <ng-template kendoDrawerTemplate>
 *     <div class="custom-drawer-content">
 *       <h3>Custom Drawer</h3>
 *       <ul>
 *         <li>Custom Item 1</li>
 *         <li>Custom Item 2</li>
 *       </ul>
 *     </div>
 *   </ng-template>
 * </kendo-drawer>
 * ```
 */
export declare class DrawerTemplateDirective {
    templateRef: TemplateRef<any>;
    constructor(templateRef: TemplateRef<any>);
    static ɵfac: i0.ɵɵFactoryDeclaration<DrawerTemplateDirective, [{ optional: true; }]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<DrawerTemplateDirective, "[kendoDrawerTemplate]", never, {}, {}, never, never, true, never>;
}
