/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { AvatarComponent } from "./avatar/avatar.component";
import { AvatarCustomMessagesComponent } from "./avatar/l10n/custom-messages.component";
import { CardActionsComponent } from "./card/card-actions.component";
import { CardBodyComponent } from "./card/card-body.component";
import { CardFooterComponent } from "./card/card-footer.component";
import { CardHeaderComponent } from "./card/card-header.component";
import { CardComponent } from "./card/card.component";
import { CardMediaDirective } from "./card/directives/card-media.directive";
import { CardSeparatorDirective } from "./card/directives/card-separator.directive";
import { CardSubtitleDirective } from "./card/directives/card-subtitle.directive";
import { CardTitleDirective } from "./card/directives/card-title.directive";
import { DrawerContainerComponent } from "./drawer/drawer-container.component";
import { DrawerContentComponent } from "./drawer/drawer-content.component";
import { DrawerComponent } from "./drawer/drawer.component";
import { DrawerFooterTemplateDirective, DrawerHeaderTemplateDirective, DrawerItemTemplateDirective, DrawerTemplateDirective } from "./drawer/template-directives";
import { ExpansionPanelTitleDirective } from "./expansionpanel/expansionpanel-title.directive";
import { ExpansionPanelComponent } from "./expansionpanel/expansionpanel.component";
import { GridLayoutComponent } from "./layouts/grid-layout.component";
import { GridLayoutItemComponent } from "./layouts/gridlayout-item.component";
import { StackLayoutComponent } from "./layouts/stack-layout.component";
import { PanelBarContentDirective } from "./panelbar/panelbar-content.directive";
import { PanelBarItemTemplateDirective } from "./panelbar/panelbar-item-template.directive";
import { PanelBarItemTitleDirective } from "./panelbar/panelbar-item-title.directive";
import { PanelBarItemComponent } from "./panelbar/panelbar-item.component";
import { PanelBarComponent } from "./panelbar/panelbar.component";
import { SplitterPaneComponent } from "./splitter/splitter-pane.component";
import { SplitterComponent } from "./splitter/splitter.component";
import { StepperCustomMessagesComponent } from "./stepper/localization/custom-messages.component";
import { StepperComponent } from "./stepper/stepper.component";
import { StepperIndicatorTemplateDirective, StepperLabelTemplateDirective, StepperStepTemplateDirective } from "./stepper/template-directives";
import { TabContentDirective } from "./tabstrip/directives/tab-content.directive";
import { TabTitleDirective } from "./tabstrip/directives/tab-title.directive";
import { TabStripCustomMessagesComponent } from "./tabstrip/localization/custom-messages.component";
import { TabStripTabComponent } from "./tabstrip/models/tabstrip-tab.component";
import { TabStripComponent } from "./tabstrip/tabstrip.component";
import { TileLayoutItemBodyComponent } from "./tilelayout/tilelayout-item-body.component";
import { TileLayoutItemHeaderComponent } from "./tilelayout/tilelayout-item-header.component";
import { TileLayoutItemComponent } from "./tilelayout/tilelayout-item.component";
import { TileLayoutComponent } from "./tilelayout/tilelayout.component";
import { TimelineCustomMessagesComponent } from "./timeline/localization/custom-messages.component";
import { TimelineCardActionsTemplateDirective } from "./timeline/templates/timeline-card-actions.directive";
import { TimelineCardBodyTemplateDirective } from "./timeline/templates/timeline-card-body.directive";
import { TimelineCardHeaderTemplateDirective } from "./timeline/templates/timeline-card-header.directive";
import { TimelineComponent } from "./timeline/timeline.component";
/**
 * Use the `KENDO_AVATAR` utility array to add all Avatar-related components and directives to a standalone Angular component.
 */
export const KENDO_AVATAR = [
    AvatarComponent,
    AvatarCustomMessagesComponent
];
/**
 * Use the `KENDO_CARD` utility array to add all Card-related components and directives to a standalone Angular component.
 */
export const KENDO_CARD = [
    CardComponent,
    CardActionsComponent,
    CardBodyComponent,
    CardFooterComponent,
    CardHeaderComponent,
    CardMediaDirective,
    CardSeparatorDirective,
    CardSubtitleDirective,
    CardTitleDirective
];
/**
 * Use the `KENDO_DRAWER` utility array to add all Drawer-related components and directives to a standalone Angular component.
 */
export const KENDO_DRAWER = [
    DrawerComponent,
    DrawerContainerComponent,
    DrawerContentComponent,
    DrawerTemplateDirective,
    DrawerFooterTemplateDirective,
    DrawerHeaderTemplateDirective,
    DrawerItemTemplateDirective
];
/**
 * Use the `KENDO_EXPANSIONPANEL` utility array to add all ExpansionPanel-related components and directives to a standalone Angular component.
 */
export const KENDO_EXPANSIONPANEL = [
    ExpansionPanelComponent,
    ExpansionPanelTitleDirective
];
/**
 * Use the `KENDO_GRIDLAYOUT` utility array to add all GridLayout-related components and directives to a standalone Angular component.
 */
export const KENDO_GRIDLAYOUT = [
    GridLayoutComponent,
    GridLayoutItemComponent
];
/**
 * Use the `KENDO_PANELBAR` utility array to add all PanelBar-related components and directives to a standalone Angular component.
 */
export const KENDO_PANELBAR = [
    PanelBarComponent,
    PanelBarItemComponent,
    PanelBarContentDirective,
    PanelBarItemTemplateDirective,
    PanelBarItemTitleDirective
];
/**
 * Use the `KENDO_SPLITTER` utility array to add all Splitter-related components and directives to a standalone Angular component.
 */
export const KENDO_SPLITTER = [
    SplitterComponent,
    SplitterPaneComponent
];
/**
 * Use the `KENDO_STACKLAYOUT` utility array to add all StackLayout-related components and directives to a standalone Angular component.
 */
export const KENDO_STACKLAYOUT = [
    StackLayoutComponent
];
/**
 * Use the `KENDO_STEPPER` utility array to add all Stepper-related components and directives to a standalone Angular component.
 */
export const KENDO_STEPPER = [
    StepperComponent,
    StepperCustomMessagesComponent,
    StepperIndicatorTemplateDirective,
    StepperLabelTemplateDirective,
    StepperStepTemplateDirective
];
/**
 * Use the `KENDO_TABSTRIP` utility array to add all TabStrip-related components and directives to a standalone Angular component.
 */
export const KENDO_TABSTRIP = [
    TabStripComponent,
    TabStripTabComponent,
    TabContentDirective,
    TabTitleDirective,
    TabStripCustomMessagesComponent
];
/**
 * Use the `KENDO_TILELAYOUT` utility array to add all TileLayout-related components and directives to a standalone Angular component.
 */
export const KENDO_TILELAYOUT = [
    TileLayoutComponent,
    TileLayoutItemBodyComponent,
    TileLayoutItemComponent,
    TileLayoutItemHeaderComponent
];
/**
 * Use the `KENDO_TIMELINE` utility array to add all Timeline-related components and directives to a standalone Angular component.
 */
export const KENDO_TIMELINE = [
    TimelineComponent,
    TimelineCustomMessagesComponent,
    TimelineCardActionsTemplateDirective,
    TimelineCardBodyTemplateDirective,
    TimelineCardHeaderTemplateDirective
];
/**
 * Use the `KENDO_LAYOUT` utility array to add all `@progress/kendo-angular-layout`-related components and directives to a standalone Angular component.
 */
export const KENDO_LAYOUT = [
    ...KENDO_AVATAR,
    ...KENDO_CARD,
    ...KENDO_DRAWER,
    ...KENDO_EXPANSIONPANEL,
    ...KENDO_GRIDLAYOUT,
    ...KENDO_PANELBAR,
    ...KENDO_SPLITTER,
    ...KENDO_STACKLAYOUT,
    ...KENDO_STEPPER,
    ...KENDO_TABSTRIP,
    ...KENDO_TILELAYOUT,
    ...KENDO_TIMELINE
];
