/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Renderer2, ElementRef, OnChanges } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * Represents the GridLayout item component. Defines the positioning and spanning of individual items within a GridLayout.
 *
 * @example
 * ```html
 * <kendo-gridlayout-item [row]="1" [col]="2" [rowSpan]="2" [colSpan]="1">
 *   <div>Grid item content</div>
 * </kendo-gridlayout-item>
 * ```
 */
export declare class GridLayoutItemComponent implements OnChanges {
    private renderer;
    private element;
    /**
     * Sets the row of the item in the GridLayout
     * ([see example]({% slug items_gridlayout %}#toc-size-and-position)).
     */
    row: number;
    /**
     * Sets the column of the item in the GridLayout
     * ([see example]({% slug items_gridlayout %}#toc-size-and-position)).
     */
    col: number;
    /**
     * Specifies how many rows the item spans ([see example]({% slug items_gridlayout %}#toc-size-and-position)).
     *
     * @default 1
     */
    rowSpan: number;
    /**
     * Specifies how many columns the item spans ([see example]({% slug items_gridlayout %}#toc-size-and-position)).
     *
     * @default 1
     */
    colSpan: number;
    constructor(renderer: Renderer2, element: ElementRef);
    ngOnInit(): void;
    ngOnChanges(): void;
    private setItemStyle;
    static ɵfac: i0.ɵɵFactoryDeclaration<GridLayoutItemComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<GridLayoutItemComponent, "kendo-gridlayout-item", never, { "row": { "alias": "row"; "required": false; }; "col": { "alias": "col"; "required": false; }; "rowSpan": { "alias": "rowSpan"; "required": false; }; "colSpan": { "alias": "colSpan"; "required": false; }; }, {}, never, ["*"], true, never>;
}
