/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Renderer2, ElementRef, AfterViewInit, SimpleChanges, OnChanges } from '@angular/core';
import { AlignSettings, Orientation } from './models';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import * as i0 from "@angular/core";
/**
 * Represents the Kendo UI StackLayout component for Angular.
 * Arranges child components in a single row or column with customizable alignment and spacing ([see overview]({% slug overview_stacklayout %})).
 *
 * @example
 * ```html
 * <kendo-stacklayout orientation="horizontal" [gap]="16">
 *   <button class="k-button">Button 1</button>
 *   <button class="k-button">Button 2</button>
 *   <button class="k-button">Button 3</button>
 * </kendo-stacklayout>
 * ```
 */
export declare class StackLayoutComponent implements AfterViewInit, OnChanges {
    private renderer;
    private element;
    private localization;
    hostClass: boolean;
    get horizontalClass(): boolean;
    get verticalClass(): boolean;
    get dir(): string;
    /**
     * Specifies the horizontal and vertical alignment of the inner StackLayout elements
     * ([see example]({% slug layout_stacklayout %}#toc-alignment)).
     */
    set align(align: AlignSettings);
    get align(): AlignSettings;
    /**
     * Specifies the gap between the inner StackLayout elements ([see example](slug:layout_stacklayout#toc-gap)).
     *
     * @default 0
     */
    gap: number | string;
    /**
     * Specifies the orientation of the StackLayout
     * ([see example]({% slug layout_stacklayout %}#toc-orientation)).
     *
     * @default 'horizontal'
     */
    orientation: Orientation;
    private _align;
    private justifyClass;
    private alignClass;
    constructor(renderer: Renderer2, element: ElementRef, localization: LocalizationService);
    ngAfterViewInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    private handleAlignClasses;
    private setGap;
    private get direction();
    static ɵfac: i0.ɵɵFactoryDeclaration<StackLayoutComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<StackLayoutComponent, "kendo-stacklayout", ["kendoStackLayout"], { "align": { "alias": "align"; "required": false; }; "gap": { "alias": "gap"; "required": false; }; "orientation": { "alias": "orientation"; "required": false; }; }, {}, never, ["*"], true, never>;
}
