/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TemplateRef } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * Defines the template directive of the PanelBar which helps to customize the item title
 * ([more information and example]({% slug templates_panelbar %}#toc-customizing-the-appearance-of-the-title)).
 * To define the template, nest an `<ng-template>` tag
 * with the `kendoPanelBarItemTitle` directive inside the `<kendo-panelbar-item>` tag.
 *
 * The `kendoPanelBarItemTitle` directive overrides the PanelBarItem [title]({% slug api_layout_panelbaritemcomponent %}#toc-title) option.
 *
 * @example
 * ```html
 * <kendo-panelbar>
 *   <kendo-panelbar-item [expanded]="true">
 *     <ng-template kendoPanelBarItemTitle>
 *       Item Title
 *     </ng-template>
 *   </kendo-panelbar-item>
 * </kendo-panelbar>
 * ```
 */
export declare class PanelBarItemTitleDirective {
    templateRef: TemplateRef<any>;
    constructor(templateRef: TemplateRef<any>);
    static ɵfac: i0.ɵɵFactoryDeclaration<PanelBarItemTitleDirective, [{ optional: true; }]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<PanelBarItemTitleDirective, "[kendoPanelBarItemTitle]", never, {}, {}, never, never, true, never>;
}
