/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { SVGIcon } from '@progress/kendo-svg-icons';
import { StepPredicateFn } from './step-predicate';
/**
 * Represents an interface for the steps of the Stepper component.
 */
export interface StepperStep {
    /**
     * Specifies the CSS classes that will be rendered on the step element of the Stepper.
     * Supports the type of values that are supported by [ngClass](link:site.data.urls.angular['ngclassapi']).
     */
    cssClass?: any;
    /**
     * Specifies the CSS styles that will be rendered on the item element of the Drawer.
     * Supports the type of values that are supported by [ngStyle](link:site.data.urls.angular['ngstyleapi']).
     */
    cssStyle?: any;
    /**
     * Specifies whether the step is disabled.
     */
    disabled?: boolean;
    /**
     * Specifies if a step is valid.
     * By default only previous steps are validated. You can override this behavior by setting the `validate` property.
     *
     * ([More information and example]({% slug step_validation_stepper %})).
     */
    isValid?: boolean | StepPredicateFn;
    /**
     * Specifies if a step should be validated. This property overrides the default validation behavior.
     *
     * ([More information and example]({% slug step_validation_stepper %})).
     */
    validate?: boolean | StepPredicateFn;
    /**
     * Specifies the name of an existing icon in a Kendo UI theme.
     * If you provide this property, the icon will be rendered inside the step indicator by a `span.k-icon` element, instead of the default numeric or text content.
     */
    icon?: string;
    /**
     * Specifies a CSS class or multiple classes separated by spaces which are applied to a `span` element.
     * Allows you to use custom icons, rendered inside the step indicator instead of the default numeric or text content.
     */
    iconClass?: string;
    /**
     * Specifies an SVG icon to be rendered inside the step indicator instead of the default numeric or text content.
     * You can use either an [existing Kendo SVG icon](slug:svgicon_list) or a custom one.
     */
    svgIcon?: SVGIcon;
    /**
     * Specifies the text content of the step label.
     */
    label?: string;
    /**
     * Specifies that the step is optional. An `Optional` label will be rendered.
     */
    optional?: boolean;
    /**
     * Specifies the text content of the step indicator.
     * If not set, the step index will be rendered by default.
     */
    text?: string;
}
