/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { SVGIcon } from "@progress/kendo-svg-icons";
import { TabStripScrollButtonsVisibility } from "./scroll-buttons-visibility";
/**
 * Configures the scrollable functionality of the TabStrip. ([See example]({% slug scrollable_tabstrip %})).
 */
export interface TabStripScrollableSettings {
    /**
     * Determines whether the TabStrip will be scrollable.
     *
     * @default true
     */
    enabled?: boolean;
    /**
     * Controls when the TabStrip scroll buttons appear.
     */
    scrollButtons?: TabStripScrollButtonsVisibility;
    /**
     * Enables scrolling with the mouse wheel, touchpad, and touch gestures on touch screens.
     * @default true
     */
    mouseScroll?: boolean;
    /**
     * Sets how many pixels the tab list scrolls when you click the scroll buttons.
     * @default 100
     */
    buttonScrollSpeed?: number;
    /**
     * Sets custom CSS classes for the previous scroll button icon.
     * You can define a single class or multiple classes separated by spaces.
     * Use this to apply custom icons.
     */
    prevButtonIcon?: string;
    /**
     * Sets custom CSS classes for the next scroll button icon.
     * You can define a single class or multiple classes separated by spaces.
     * Use this to apply custom icons.
     */
    nextButtonIcon?: string;
    /**
     * Sets an SVG icon for the previous button.
     * You can use an [existing Kendo SVG icon](slug:svgicon_list) or provide a custom one.
     */
    prevSVGButtonIcon?: SVGIcon;
    /**
     * Sets an SVG icon for the next button.
     * You can use an [existing Kendo SVG icon](slug:svgicon_list) or provide a custom one.
     */
    nextSVGButtonIcon?: SVGIcon;
    /**
     * Specifies where to position the scroll buttons.
     */
    scrollButtonsPosition?: TabStripScrollButtonsPosition;
}
/**
 * Specifies where to position the scroll buttons.
 */
export type TabStripScrollButtonsPosition = 'start' | 'end' | 'split';
/**
 * @hidden
 */
export declare const normalizeScrollableSettings: (settings: any) => any;
