/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { QueryList } from '@angular/core';
import { SVGIcon } from '@progress/kendo-svg-icons';
import { TabContentDirective } from '../directives/tab-content.directive';
import { TabTitleDirective } from '../directives/tab-title.directive';
import { TabTemplateDirective } from '../directives/tab.directive';
import * as i0 from "@angular/core";
/**
 * Represents the Kendo UI TabStrip tab component.
 * Use this component to define individual tabs within a TabStrip.
 *
 * @example
 * ```html
 * <kendo-tabstrip>
 *   <kendo-tabstrip-tab title="Home" [selected]="true">
 *     <ng-template kendoTabContent>
 *       Home content here
 *     </ng-template>
 *   </kendo-tabstrip-tab>
 * </kendo-tabstrip>
 * ```
 */
export declare class TabStripTabComponent {
    /**
     * Sets the title text for the tab ([see example](slug:tabs_tabstrip#toc-tab-titles)).
     */
    title: string;
    /**
     * Disables the tab and prevents user interaction ([see example]({% slug tabs_tabstrip %}#toc-disabled-tabs)).
     *
     * @default false
     */
    disabled: boolean;
    /**
     * Specifies the CSS classes to apply to the `tab` element.
     * Accepts the same values as [`ngClass`](link:site.data.urls.angular['ngclassapi']).
     */
    cssClass: any;
    /**
     * Specifies the CSS styles to apply to the `tab` element.
     * Accepts the same values as [`ngStyle`](link:site.data.urls.angular['ngstyleapi']).
     */
    cssStyle: any;
    /**
     * Selects the tab when the TabStrip loads
     * ([see example](slug:tabs_tabstrip#toc-selected-tab)).
     */
    selected: boolean;
    /**
     * Shows a close button inside the tab when set to `true`.
     * This setting overrides the TabStrip `closable` option.
     */
    closable: boolean;
    /**
     * Sets the name of an existing font icon in the Kendo UI theme for the close button.
     * This setting overrides the TabStrip `closeIcon` option.
     */
    closeIcon: string;
    /**
     * Sets custom CSS classes for the close button icon.
     * You can define a single class or multiple classes separated by spaces.
     * This setting overrides the TabStrip `closeIcon` option.
     */
    closeIconClass: string;
    /**
     * Sets an SVG icon for the close button.
     * You can use an [existing Kendo SVG icon](slug:svgicon_list) or provide a custom one.
     */
    closeSVGIcon: SVGIcon;
    get tabContent(): TabContentDirective;
    get tabTitle(): TabTitleDirective;
    get tabTemplate(): TabTemplateDirective;
    _tabDirective: QueryList<TabTemplateDirective>;
    _tabContent: QueryList<TabContentDirective>;
    _tabTitleDirective: QueryList<TabTitleDirective>;
    /**
     * @hidden
     *
     * Currently only disabled tabs can be focused. Otherwise they will be
     * immediately selected
     */
    focused: boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<TabStripTabComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TabStripTabComponent, "kendo-tabstrip-tab", ["kendoTabStripTab"], { "title": { "alias": "title"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "cssClass": { "alias": "cssClass"; "required": false; }; "cssStyle": { "alias": "cssStyle"; "required": false; }; "selected": { "alias": "selected"; "required": false; }; "closable": { "alias": "closable"; "required": false; }; "closeIcon": { "alias": "closeIcon"; "required": false; }; "closeIconClass": { "alias": "closeIconClass"; "required": false; }; "closeSVGIcon": { "alias": "closeSVGIcon"; "required": false; }; }, {}, ["_tabDirective", "_tabContent", "_tabTitleDirective"], never, true, never>;
}
