/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { PreventableEvent } from '@progress/kendo-angular-common';
import { TileLayoutItemComponent } from './tilelayout-item.component';
/**
 * Arguments for the `reorder` event.
 * The event fires when you change the order or starting positions of items through the UI.
 * You can prevent this event to cancel the reorder operation.
 */
export declare class TileLayoutReorderEvent extends PreventableEvent {
    item: TileLayoutItemComponent;
    items: TileLayoutItemComponent[];
    newIndex: number;
    oldIndex: number;
    newCol?: number;
    oldCol?: number;
    newRow?: number;
    oldRow?: number;
    /**
     * Constructs the event arguments for the `reorder` event.
     * @param item - The TileLayoutItem being reordered.
     * @param items - The TileLayoutItem collection that holds the currently rendered items and their internal state.
     * @param newIndex - The new order index of the reordered item used to determine its positioning relative to the other items.
     * @param oldIndex - The initial order index of the reordered item used to determine its positioning relative to the other items.
     * @param newCol - The new start column of the reordered item.
     * @param oldCol - The initial start column of the reordered item.
     * @param newRow - The new start row of the reordered item.
     * @param oldRow - The initial start row of the reordered item.
     * @hidden
     */
    constructor(item: TileLayoutItemComponent, items: TileLayoutItemComponent[], newIndex: number, oldIndex: number, newCol?: number, oldCol?: number, newRow?: number, oldRow?: number);
}
