/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { PreventableEvent } from '@progress/kendo-angular-common';
import { TileLayoutItemComponent } from './tilelayout-item.component';
/**
 * Arguments for the `resize` event.
 * The `resize` event fires when you change any item size through the UI.
 * You can prevent this event to stop the resize operation.
 */
export declare class TileLayoutResizeEvent extends PreventableEvent {
    item: TileLayoutItemComponent;
    items: TileLayoutItemComponent[];
    newRowSpan: number;
    oldRowSpan: number;
    newColSpan: number;
    oldColSpan: number;
    /**
     * Constructs the event arguments for the `resize` event.
     * @param item - The TileLayoutItem being resized
     * @param items - The TileLayoutItem collection
     * @param newRowSpan - The new rowSpan of the resized item
     * @param oldRowSpan - The initial rowSpan of the resized item
     * @param newColSpan - The new colSpan of the resized item
     * @param oldColSpan - The initial colSpan of the resized item
     * @hidden
     */
    constructor(item: TileLayoutItemComponent, items: TileLayoutItemComponent[], newRowSpan: number, oldRowSpan: number, newColSpan: number, oldColSpan: number);
}
