/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { AnchorTarget } from "./anchor-target";
/**
 * Represents the event model of the Timeline. These are the interface fields that the Timeline events use.
 */
export interface TimelineEvent {
    /**
     * Specifies the text that is rendered as title.
     */
    title: string;
    /**
     * Specifies the text that is rendered under the title.
     */
    subtitle?: string;
    /**
     * Specifies the text that is rendered as body of the event card.
     */
    description?: string;
    /**
     * Represents an event point on the axis.
     */
    date: Date;
    /**
     * Specifies if the event card is expanded or collapsed by default.
     */
    expanded?: boolean;
    /**
     * Specifies the images that are rendered under the description.
     */
    images?: Array<{
        src: string;
        alt?: string;
    }>;
    /**
     * Specifies the corresponding links that are rendered under the images.
     */
    actions?: Array<{
        text: string;
        url: string;
        target?: AnchorTarget;
    }>;
    /**
     * @hidden
     */
    flag?: number;
}
