/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TemplateRef } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * Specifies the header of each timeline card. To define a header template, nest an `<ng-template>` tag
 * with the `kendoTimelineCardHeaderTemplate` directive inside the `<kendo-timeline>` tag.
 *
 * The following values are available as context variables:
 * - `let-event="event"` (`TimelineEvent`)&mdash;The current card's event. Also available as implicit context variable.
 * - `let-index="index"` (`number`)&mdash;The current event index.
 *
 * @example
 * ```html
 * <kendo-timeline [events]="events">
 *   <ng-template kendoTimelineCardHeaderTemplate let-event let-index="index">
 *     <span class="k-event-title">Title: {{ event.title }}</span>
 *     <div kendoCardSubtitle>Event number {{ index }}</div>
 *   </ng-template>
 * </kendo-timeline>
 * ```
 */
export declare class TimelineCardHeaderTemplateDirective {
    templateRef: TemplateRef<any>;
    constructor(templateRef: TemplateRef<any>);
    static ɵfac: i0.ɵɵFactoryDeclaration<TimelineCardHeaderTemplateDirective, [{ optional: true; }]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<TimelineCardHeaderTemplateDirective, "[kendoTimelineCardHeaderTemplate]", never, {}, {}, never, never, true, never>;
}
